@@ -6,7 +6,7 @@ BEGIN {
     use Excel::Template::Base;
     use vars qw ($VERSION @ISA);
 
-    $VERSION  = '0.20';
+    $VERSION  = '0.21';
     @ISA      = qw( Excel::Template::Base );
 }
 
@@ -14,6 +14,16 @@ use File::Basename;
 use XML::Parser;
 use IO::Scalar;
 
+use constant RENDER_NML => 'normal';
+use constant RENDER_BIG => 'big';
+use constant RENDER_XML => 'xml';
+
+my %renderers = (
+    RENDER_NML, 'Spreadsheet::WriteExcel',
+    RENDER_BIG, 'Spreadsheet::WriteExcel::Big',
+    RENDER_XML, 'Spreadsheet::WriteExcelXML',
+);
+
 sub new
 {
     my $class = shift;
@@ -23,8 +33,21 @@ sub new
         if defined $self->{FILENAME};
 
     my @renderer_classes = ( 'Spreadsheet::WriteExcel' );
-    if (exists $self->{BIG_FILE} && $self->{BIG_FILE})
+
+    if (exists $self->{RENDERER} && $self->{RENDERER})
     {
+        if (exists $renderers{ lc $self->{RENDERER} })
+        {
+            unshift @renderer_classes, $renderers{ lc $self->{RENDERER} };
+        }
+        elsif ($^W)
+        {
+            warn "'$self->{RENDERER}' is not recognized\n";
+        }
+    }
+    elsif (exists $self->{BIG_FILE} && $self->{BIG_FILE})
+    {
+        warn "Use of BIG_FILE is deprecated.\n";
         unshift @renderer_classes, 'Spreadsheet::WriteExcel::Big';
     }
 
@@ -115,7 +138,7 @@ sub parse_xml
 
                 my $name = uc shift;
 
-                my $node = Excel::Template::Factory->create_node($name, @_);
+                my $node = Excel::Template::Factory->_create_node($name, @_);
                 die "'$name' (@_) didn't make a node!\n" unless defined $node;
 
                 if ( $node->isa( 'WORKBOOK' ) )
@@ -181,7 +204,7 @@ sub _prepare_output
     my $self = shift;
     my ($xls) = @_;
 
-    my $context = Excel::Template::Factory->create(
+    my $context = Excel::Template::Factory->_create(
         'CONTEXT',
 
         XLS       => $xls,
@@ -220,7 +243,7 @@ For example, test.xml:
 Now, create a small program to use it:
 
   #!/usr/bin/perl -w
-  use Excel::Template
+  use Excel::Template;
 
   # Create the Excel template
   my $template = Excel::Template->new(
@@ -270,19 +293,52 @@ This creates a Excel::Template object. If passed a FILENAME parameter, it will
 parse the template in the given file. (You can also use the parse() method,
 described below.)
 
-new() accepts an optional BIG_FILE parameter. This will attempt to change the
-renderer from L<Spreadsheet::WriteExcel> to L<Spreadsheet::WriteExcel::Big>. You
-must already have L<Spreadsheet::WriteExcel::Big> installed on your system.
+=head3 Parameters
 
-new() also accepts an optional USE_UNICODE parameter. This will use
-L<Unicode::String> to represent strings instead of Perl's internal string
-handling. You must already have L<Unicode::String> installed on your system.
+=over 4
+
+=item * RENDERER
+
+The default rendering engine is Spreadsheet::WriteExcel. You may, if you choose, change that to another choice. The legal values are:
+
+=over 4
+
+=item * Excel::Template->RENDER_NML
+
+This is the default of Spreadsheet::WriteExcel.
+
+=item * Excel::Template->RENDER_BIG
+
+This attempts to load Spreadsheet::WriteExcel::Big.
+
+=item * Excel::Template->RENDER_XML
+
+This attempts to load Spreadsheet::WriteExcelXML.
+
+=back
+
+=item * USE_UNICODE
+
+This will use L<Unicode::String> to represent strings instead of Perl's internal string handling. You must already have L<Unicode::String> installed on your system.
 
 The USE_UNICODE parameter will be ignored if you are using Perl 5.8 or higher as
 Perl's internal string handling is unicode-aware.
 
-NOTE: L<Spreadsheet::WriteExcel::Big> and mod_perl clash for some reason. This
-is outside of my control.
+NOTE: Certain older versions of L<OLE::Storage_Lite> and mod_perl clash for some
+reason. Upgrading to the latest version of L<OLE::Storage_Lite> should fix the
+problem.
+
+=back
+
+=head3 Deprecated
+
+=over 4
+
+=item * BIG_FILE
+
+Instead, use RENDERER => Excel::Template->RENDER_BIG
+
+=back
 
 =head2 param()
 
@@ -305,6 +361,10 @@ It will act just like HTML::Template's output() method, returning the resultant
 file as a stream, usually for output to the web. (This is when the actual
 merging of the template and the parameters occurs.)
 
+=head2 register()
+
+This allows you to register a class as handling a node. q.v. L<Excel::Template::Factory> for more info.
+
 =head1 SUPPORTED NODES
 
 This is a partial list of nodes. See the other classes in this distro for more
@@ -365,7 +425,7 @@ This is a BACKREF for a number of identically-named cells.
 This is a variable. It is generally used when the 'text' attribute isn't
 sufficient.
 
-=back 4
+=back
 
 =head1 BUGS
 
@@ -382,9 +442,9 @@ applications.
 
 =head1 CONTRIBUTORS
 
-There is a mailing list at http://groups.google.com/group/ExcelTemplate
+There is a mailing list at http://groups.google.com/group/ExcelTemplate or exceltemplate@googlegroups.com
 
-Robert Graff -
+=head2 Robert Graff
 
 =over 4
 
@@ -392,7 +452,47 @@ Robert Graff -
 
 =item * Fixing several bugs in worksheet naming
 
-=back 4
+=back
+
+=head1 TEST COVERAGE
+
+I used Devel::Cover to test the coverage of my tests. Every release, I intend to improve these numbers.
+
+Excel::Template is also part of the CPAN Kwalitee initiative, being one of the top 100 non-core modules downloaded from CPAN. If you wish to help out, please feel free to contribute tests, patches, and/or suggestions.
+
+---------------------------- ------ ------ ------ ------ ------ ------ ------
+File                           stmt branch   cond    sub    pod   time  total
+---------------------------- ------ ------ ------ ------ ------ ------ ------
+blib/lib/Excel/Template.pm     90.0   57.1   50.0   90.5  100.0   26.0   80.8
+...ib/Excel/Template/Base.pm   83.3   50.0   66.7   75.0   88.9    8.8   80.0
+...cel/Template/Container.pm   46.3   20.0   33.3   58.3   85.7    4.6   47.7
+...emplate/Container/Bold.pm  100.0    n/a    n/a  100.0    0.0    0.6   95.0
+.../Container/Conditional.pm   58.5   52.3   66.7   75.0   66.7    0.7   58.4
+...plate/Container/Format.pm  100.0    n/a    n/a  100.0    0.0    0.8   96.6
+...plate/Container/Hidden.pm  100.0    n/a    n/a  100.0    0.0    0.2   95.0
+...plate/Container/Italic.pm  100.0    n/a    n/a  100.0    0.0    0.2   95.0
+...plate/Container/Locked.pm  100.0    n/a    n/a  100.0    0.0    0.1   95.0
+...emplate/Container/Loop.pm   55.6   40.0   50.0   77.8   75.0    0.5   56.6
+...late/Container/Outline.pm   71.4    n/a    n/a   80.0    0.0    0.0   70.0
+...Template/Container/Row.pm  100.0   75.0    n/a  100.0   50.0    0.3   93.8
+...mplate/Container/Scope.pm  100.0    n/a    n/a  100.0    n/a    0.1  100.0
+...plate/Container/Shadow.pm  100.0    n/a    n/a  100.0    0.0    0.1   95.0
+...te/Container/Strikeout.pm  100.0    n/a    n/a  100.0    0.0    0.1   95.0
+...ate/Container/Workbook.pm  100.0    n/a    n/a  100.0    n/a    1.1  100.0
+...te/Container/Worksheet.pm   94.1   50.0    n/a  100.0    0.0    0.9   88.0
+...Excel/Template/Context.pm   83.1   53.4   54.2   95.0   92.9   19.2   75.2
+...Excel/Template/Element.pm  100.0    n/a    n/a  100.0    n/a    0.5  100.0
+...mplate/Element/Backref.pm  100.0   50.0   33.3  100.0    0.0    0.1   87.1
+.../Template/Element/Cell.pm   95.8   65.0   80.0  100.0   66.7    3.6   86.9
+...mplate/Element/Formula.pm  100.0    n/a    n/a  100.0    0.0    0.3   94.1
+...Template/Element/Range.pm  100.0   66.7    n/a  100.0   66.7    0.2   93.3
+...l/Template/Element/Var.pm  100.0    n/a    n/a  100.0    0.0    0.2   94.1
+...Excel/Template/Factory.pm   57.1   34.6    n/a   88.9  100.0   15.4   55.2
+.../Excel/Template/Format.pm   98.3   81.2   33.3  100.0  100.0    9.9   93.2
+...xcel/Template/Iterator.pm   85.2   70.6   70.6   84.6   87.5    2.0   80.4
+...el/Template/TextObject.pm   92.9   62.5   33.3  100.0   50.0    3.6   83.0
+Total                          83.0   55.6   57.0   91.1   98.7  100.0   78.6
+---------------------------- ------ ------ ------ ------ ------ ------ ------
 
 =head1 COPYRIGHT
 
